summaryrefslogtreecommitdiffstats
path: root/libkdepim/ksubscription.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /libkdepim/ksubscription.h
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libkdepim/ksubscription.h')
-rw-r--r--libkdepim/ksubscription.h29
1 files changed, 15 insertions, 14 deletions
diff --git a/libkdepim/ksubscription.h b/libkdepim/ksubscription.h
index cb177d20c..f9ce044aa 100644
--- a/libkdepim/ksubscription.h
+++ b/libkdepim/ksubscription.h
@@ -45,20 +45,20 @@ class KAccount;
class KDE_EXPORT KGroupInfo
{
public:
- enum Status {
+ enum tqStatus {
unknown,
readOnly,
postingAllowed,
moderated
};
- KGroupInfo( const TQString &name, const TQString &description = TQString::null,
+ KGroupInfo( const TQString &name, const TQString &description = TQString(),
bool newGroup = false, bool subscribed = false,
- Status status = unknown, TQString path = TQString::null );
+ tqStatus status = unknown, TQString path = TQString() );
TQString name, description;
bool newGroup, subscribed;
- Status status;
+ tqStatus status;
TQString path;
bool operator== (const KGroupInfo &gi2);
@@ -69,7 +69,7 @@ class KDE_EXPORT KGroupInfo
//==========================================================================
/** A class representing a single group item (what's that?) */
-class KDE_EXPORT GroupItem : public QCheckListItem
+class KDE_EXPORT GroupItem : public TQCheckListItem
{
public:
GroupItem( TQListView *v, const KGroupInfo &gi, KSubscription* browser,
@@ -84,10 +84,10 @@ class KDE_EXPORT GroupItem : public QCheckListItem
void setInfo( KGroupInfo info );
/**
* Get/Set the original parent
*/
TQListViewItem* originalParent() { return mOriginalParent; }
- void setOriginalParent( TQListViewItem* parent ) { mOriginalParent = parent; }
+ void setOriginalParent( TQListViewItem* tqparent ) { mOriginalParent = tqparent; }
/**
* Get/Set the last open state
@@ -132,27 +132,27 @@ class KDE_EXPORT GroupItem : public QCheckListItem
/**
* Reimplemented
* Calls TQListViewItem or QCheckListItem
*/
virtual void paintCell( TQPainter * p, const TQColorGroup & cg,
int column, int width, int align );
/**
* Reimplemented
* Calls TQListViewItem or QCheckListItem
*/
virtual void paintFocus( TQPainter *, const TQColorGroup & cg,
const TQRect & r );
/**
* Reimplemented
* Calls TQListViewItem or QCheckListItem
*/
virtual int width( const TQFontMetrics&, const TQListView*, int column) const;
/**
* Reimplemented
* Calls TQListViewItem or QCheckListItem
*/
virtual void setup();
@@ -188,6 +188,7 @@ class KDE_EXPORT GroupItem : public QCheckListItem
class KDE_EXPORT KSubscription : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
@@ -198,8 +199,8 @@ class KDE_EXPORT KSubscription : public KDialogBase
Right
};
- KSubscription( TQWidget *parent, const TQString &caption, KAccount* acct,
- int buttons = 0, const TQString &user1 = TQString::null,
+ KSubscription( TQWidget *tqparent, const TQString &caption, KAccount* acct,
+ int buttons = 0, const TQString &user1 = TQString(),
bool descriptionColumn = true );
~KSubscription();
@@ -280,7 +281,7 @@ class KDE_EXPORT KSubscription : public KDialogBase
* criteria changed
*/
void filterChanged( TQListViewItem* item = 0,
- const TQString & text = TQString::null );
+ const TQString & text = TQString() );
/**
* The amount of items that are visible and enabled
@@ -84,10 +84,10 @@ class KDE_EXPORT GroupItem : public QCheckListItem
void setInfo( KGroupInfo info );
/**
- * Get/Set the original parent
+ * Get/Set the original tqparent
*/
TQListViewItem* originalParent() { return mOriginalParent; }
@@ -132,27 +132,27 @@ class KDE_EXPORT GroupItem : public QCheckListItem
/**
* Reimplemented
- * Calls TQListViewItem or QCheckListItem
+ * Calls TQListViewItem or TQCheckListItem
*/
virtual void paintCell( TQPainter * p, const TQColorGroup & cg,
@@ -132,27 +132,27 @@ class KDE_EXPORT GroupItem : public QCheckListItem
/**
* Reimplemented
- * Calls TQListViewItem or QCheckListItem
+ * Calls TQListViewItem or TQCheckListItem
*/
virtual void paintFocus( TQPainter *, const TQColorGroup & cg,
@@ -132,27 +132,27 @@ class KDE_EXPORT GroupItem : public QCheckListItem
/**
* Reimplemented
- * Calls TQListViewItem or QCheckListItem
+ * Calls TQListViewItem or TQCheckListItem
*/
virtual int width( const TQFontMetrics&, const TQListView*, int column) const;
@@ -132,27 +132,27 @@ class KDE_EXPORT GroupItem : public QCheckListItem
/**
* Reimplemented
- * Calls TQListViewItem or QCheckListItem
+ * Calls TQListViewItem or TQCheckListItem
*/
virtual void setup();